using Documenter, FHist
using Pluto: Configuration.CompilerOptions
using PlutoStaticHTML

notebooks = [
    "Makie Plotting",
    "Plots Plotting",
]

include("build.jl")

build()
md_files = markdown_files()
T = [t => f for (t, f) in zip(notebooks, md_files)]

makedocs(;
    modules=[FHist],
    format = Documenter.HTML(
        prettyurls = get(ENV, "CI", nothing) == "true",
        size_threshold = 5*10^6
        # assets = ["assets/logo.ico"],
    ),
    pages=[
        "Introduction" => "index.md",
        "User Guide" => Any[
            "Creating Histogram" => "start.md",
            "Using Histogram" => "usage.md",
        ],
        "APIs Reference" => "api.md",
        "Writing to `.root`" => "writingtoroot.md",
        "Writing to `HDF5`" => "writingtohdf5.md",
        "Plotting Tutorials" => T,
    ],
    sitename="FHist.jl",
    authors="Jerry Ling"
)

deploydocs(;
    repo="github.com/Moelf/FHist.jl",
    push_preview = true
)
